==> yagroup_pay-0.1.1.tar.gz: yagroup_pay-0.1.1/yagroup_pay/routers/rate.py <==
#
# (c) 2025, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from nexium_api import route

from services import RateFacadeService
from shared import UpdateRatesRequestData, UpdateRatesResponseData, GetRatesRequestData, GetRatesResponseData, \
    CalculateRateRequestData, CalculateRateResponseData
from .base import Router


class RateRouter(Router):
    prefix = '/rates'

    @route(
        path='/update',
        request_data=UpdateRatesRequestData,
        response_data=UpdateRatesResponseData,
        func=RateFacadeService().update,
    )
    async def update(self):
        pass

    @route(
        path='/get',
        request_data=GetRatesRequestData,
        response_data=GetRatesResponseData,
        func=RateFacadeService().get,
        response_field='rates',
    )
    async def get(self):
        pass

    @route(
        path='/calculate',
        request_data=CalculateRateRequestData,
        response_data=CalculateRateResponseData,
        func=RateFacadeService().calculate,
    )
    async def calculate(self):
        pass

==> yagroup_pay-0.1.4.tar.gz: yagroup_pay-0.1.4/yagroup_pay/routers/rate.py <==
#
# (c) 2025, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from nexium_api import route

from yagroup_pay.shared import UpdateRatesRequestData, UpdateRatesResponseData, GetRatesRequestData, GetRatesResponseData, \
    CalculateRateRequestData, CalculateRateResponseData
from .base import Router


class RateRouter(Router):
    facade_service = 'RateFacadeService'
    prefix = '/rates'

    @route(
        path='/update',
        request_data=UpdateRatesRequestData,
        response_data=UpdateRatesResponseData,
    )
    async def update(self):
        pass

    @route(
        path='/get',
        request_data=GetRatesRequestData,
        response_data=GetRatesResponseData,
        response_field='rates',
    )
    async def get(self):
        pass

    @route(
        path='/calculate',
        request_data=CalculateRateRequestData,
        response_data=CalculateRateResponseData,
    )
    async def calculate(self):
        pass
